<?php
/**
* @file
* @brief    Liturgical year module.
* @package  mod_liturgicalyear
* @author   Levente Hunyadi
* @version  1.0.5
* @remarks  Copyright (C) 2009-2011 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/liturgicalyear
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

require(dirname(__FILE__).DIRECTORY_SEPARATOR.'helper.php');

class modLiturgicalYear {
	public static function get_solemnities($params) {
		$jd_today = jd_get_local_date();
		$days_earlier = $params->get('days_earlier', 25);
		$days_later  = $params->get('days_later', 50);
		$show_days = $params->get('show_days', true);
		$show_date = $params->get('show_date', true);
		$show_events = $params->get('show_events', false);
		if ($show_events === false) {  // stores whether to show or hide single events
			$show_events = modLiturgicalYearHelper::get_event_observance('commonly_observed');
		}

		$jd_from = $jd_today - $days_earlier;
		$jd_until = $jd_today + $days_later;

		// get liturgical (ecclesiastical) events within a given Julian day count range
		$gd_from = cal_from_jd($jd_from, CAL_GREGORIAN);
		$gd_until = cal_from_jd($jd_until, CAL_GREGORIAN);
		$events = array();  // event array whose keys are Julian day counts
		for ($year = $gd_from['year']; $year <= $gd_until['year']; $year++) {  // retrieve events for all years spanned
			$events_key_jd = modLiturgicalYearHelper::get_event_dates($year);  // event array whose keys are event keys
			foreach ($events_key_jd as $event_key => $event_jd) {
				if ($event_jd >= $jd_from && $event_jd <= $jd_until) {  // event is within required range
					if (in_array($event_key, $show_events)) {
						$events[$event_jd] = $event_key;  // add event to list of events in range
					}
				}
			}
		}
		ksort($events);
		return array(
			'date' => $jd_today,
			'show_days' => $show_days,
			'show_date' => $show_date,
			'events' => $events);
	}
}

$solemnities = modLiturgicalYear::get_solemnities( $params );

require(JModuleHelper::getLayoutPath("mod_liturgicalyear"));